Struct ZxdgExporterV2
pub struct ZxdgExporterV2 { /* private fields */ }wayland and Linux only.Expand description
interface for exporting surfaces
A global interface used for exporting surfaces that can later be imported using xdg_importer.
This interface has no events.
Implementations
impl ZxdgExporterV2
impl ZxdgExporterV2
pub fn destroy(&self)
pub fn destroy(&self)
destroy the xdg_exporter object
Notify the compositor that the xdg_exporter object will no longer be used.
pub fn export_toplevel<U, D>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
udata: U,
) -> ZxdgExportedV2
pub fn export_toplevel<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> ZxdgExportedV2
export a toplevel surface
The export_toplevel request exports the passed surface so that it can later be imported via xdg_importer. When called, a new xdg_exported object will be created and xdg_exported.handle will be sent immediately. See the corresponding interface and event for details.
A surface may be exported multiple times, and each exported handle may be used to create an xdg_imported multiple times. Only xdg_toplevel equivalent surfaces may be exported, otherwise an invalid_surface protocol error is sent.